@@ -15,7 +15,14 @@ else:
     from . import read_config as rc
     from . import anutils as an
 
-__VERSION__ = "0.0.7"
+__IPV__ = False
+try:
+    import ipyvolume as ipv
+    __IPV__ = True
+except:
+    print("Unable to import Ipyvolume")
+
+__VERSION__ = "0.0.12"
 
 """
     A module to analyze cytosim simulations
@@ -55,6 +62,8 @@ class Frame():
         self.id = number
         self.initialize(*args, **kwargs)
 
+        self.all_sets = [self.fibers, self.couples, self.objects]
+
     def initialize(self, *args,
                    fibers_lines={}, couples_lines={}, objects_lines={},
                    config=None, options={}, **kwargs):
@@ -83,6 +92,19 @@ class Frame():
         self.couples_analysis = an.make_analysis(self.couples,*args,**kwargs)
         self.objects_analysis = an.make_analysis(self.objects, *args, **kwargs)
 
+    def show(self,*args, options=None, **kwargs):
+        for set in self.all_sets:
+            for name, set in set.items():
+                opts={}
+                if options is not None:
+                    try:
+                        opts = options[name]
+                    except:
+                        opts = {}
+                set.show(*args, **opts,  **kwargs)
+
+        return None
+
 
 class Simulation(list):
     """
@@ -100,6 +122,8 @@ class Simulation(list):
         self.name='frame'
         self.id = 0
         self.n_frames=0
+        self.shown = False
+        self.figure = None
 
         # Actual initialization
         self.initialize(*args,**kwargs)
@@ -161,11 +185,10 @@ class Simulation(list):
 
     def analyze(self, frame, *args, analyzer=None, **kwargs):
 
-        analysis={}
+        analysis = {'id': frame.id}
         if analyzer is not None:
             for name,func in analyzer.items():
-                analysis[name]=func(frame)
-        analysis['frame.id']=frame.id
+                analysis[name] = func(frame)
 
         return analysis
 
@@ -191,3 +214,21 @@ class Simulation(list):
             datas = pd.DataFrame(columns=keys)
             datas.loc[self.id] = [analysis[key] for key in keys]
             self.analysis = datas
+
+    def show(self, number, *args, **kwargs):
+        if not __IPV__:
+            raise ValueError("Could not import module iPyVolume")
+        else:
+            #fig = ipv.figure()
+            if self.figure is None:
+                self.figure = ipv.figure()
+            self[number].show(*args, **kwargs)
+            if not self.shown:
+                ipv.show()
+                self.shown = True
+
+    def show_single(self, number, *args, **kwargs):
+        if self.figure is not None:
+            ipv.clear()
+        self.show(number,*args,**kwargs)
+        ipv.show()
\ No newline at end of file
