@@ -2,7 +2,6 @@
 ####### PACKAGES
 import numpy as np
 import sio_tools as sio
-from . import anutils as an
 from .objects import Object_set
 
 ### This should definitely be in a yaml file
@@ -12,6 +11,13 @@ __N_DIM__= 3
 # This is just convenient
 __NARR__= np.array([None])
 
+# Check if we can plot stuff
+__IPV__ = False
+try:
+    import ipyvolume as ipv
+    __IPV__ = True
+except:
+    print("Unable to import Ipyvolume")
 
 # a bit of cleanup needed for creation
 class Fiber_set(Object_set):
@@ -86,7 +92,7 @@ class Fiber_set(Object_set):
 
     def analyze(self, fiber, analyzer=None, *args, **kwargs):
 
-        analysis = {}
+        analysis = {'id' : fiber.id}
         if analyzer is not None:
             for name, func in analyzer.items():
                 analysis[name] = func(fiber)
@@ -114,6 +120,29 @@ class Fiber_set(Object_set):
         else:
             return 0.0
 
+    def show(self,*args, sorter=None, plotter=None, **kwargs):
+        if __IPV__:
+            if sorter is not None:
+                fibs = filter(sorter, self)
+            else:
+                fibs = self
+
+            if plotter is not None:
+                return plotter(fibs, *args, **kwargs)
+            else:
+                return self.plot_fibers(fibs, *args, **kwargs)
+
+        else:
+            return False
+
+    def plot_fibers(self, fibers, *args, **kwargs):
+        for fiber in fibers:
+            self.plot_fiber(fiber, *args, **kwargs)
+        return True
+
+    def plot_fiber(self, fiber, *args, **kwargs):
+        p=ipv.plot(fiber[:,0], fiber[:,1], fiber[:,2], **kwargs)
+
 
 ###### A class to contain a single filament : trying to make it leaner !
 
